==> opigno_lms-7.x-1.19-core.tar.gz: opigno_lms-7.x-1.19/profiles/opigno_lms/modules/contrib/h5p/modules/h5peditor/h5peditor/language/en.js <==
H5PEditor.language.core = {
  missingTranslation: '[Missing translation :key]',
  loading: 'Loading :type, please wait...',
  selectLibrary: 'Select the library you wish to use for your content.',
  unknownFieldPath: 'Unable to find ":path".',
  notImageField: '":path" is not an image.',
  notImageOrDimensionsField: '":path" is not an image or dimensions field.',
  requiredProperty: 'The :property is required and must have a value.',
  onlyNumbers: 'The :property value can only contain numbers.',
  exceedsMax: 'The :property value exceeds the maximum of :max.',
  exceedsMin: 'The :property value exceeds the minimum of :min.',
  outOfStep: 'The :property value can only be changed in steps of :step.',
  addFile: 'Add file',
  removeFile: 'Remove file',
  confirmRemoval: 'Are you sure you wish to remove this :type?',
  changeFile: 'Change file',
  semanticsError: 'Semantics error: :error',
  missingProperty: 'Field :index is missing its :property property.',
  expandCollapse: 'Expand/Collapse',
  addEntity: 'Add :entity',
  tooLong: 'Field value is too long, should contain :max letters or less.',
  invalidFormat: 'Field value contains an invalid format or characters that are forbidden.',
  confirmChangeLibrary: 'Are you sure you wish to change library?',
  moreLibraries: 'Look for <a href="http://h5p.org/content-types-and-applications" target="_blank">more content types</a> on h5p.org',
  commonFields: 'Settings and texts',
  commonFieldsDescription: 'Here you can edit settings or translate texts used in this content.',
  uploading: 'Uploading, please wait...',
  noFollow: 'Cannot follow field ":path".',
  editCopyright: 'Edit copyright',
  close: 'Close',
  tutorialAvailable: 'Tutorial available',
  editMode: 'Redigeringsmodus',
  listLabel: 'Liste'
};

==> opigno_lms-7.x-1.20-core.tar.gz: opigno_lms-7.x-1.20/profiles/opigno_lms/modules/contrib/h5p/modules/h5peditor/h5peditor/language/en.js <==
H5PEditor.language.core = {
  missingTranslation: '[Missing translation :key]',
  loading: 'Loading :type, please wait...',
  selectLibrary: 'Select the library you wish to use for your content.',
  unknownFieldPath: 'Unable to find ":path".',
  notImageField: '":path" is not an image.',
  notImageOrDimensionsField: '":path" is not an image or dimensions field.',
  requiredProperty: 'The :property is required and must have a value.',
  onlyNumbers: 'The :property value can only contain numbers.',
  exceedsMax: 'The :property value exceeds the maximum of :max.',
  exceedsMin: 'The :property value exceeds the minimum of :min.',
  outOfStep: 'The :property value can only be changed in steps of :step.',
  addFile: 'Add file',
  removeFile: 'Remove file',
  confirmRemoval: 'Are you sure you wish to remove this :type?',
  changeFile: 'Change file',
  semanticsError: 'Semantics error: :error',
  missingProperty: 'Field :index is missing its :property property.',
  expandCollapse: 'Expand/Collapse',
  addEntity: 'Add :entity',
  tooLong: 'Field value is too long, should contain :max letters or less.',
  invalidFormat: 'Field value contains an invalid format or characters that are forbidden.',
  confirmChangeLibrary: 'By doing this you will loose all work done with the current content type. Are you sure you wish to change content type?',
  moreLibraries: 'Look for <a href="http://h5p.org/content-types-and-applications" target="_blank">more content types</a> on h5p.org',
  commonFields: 'Settings and texts',
  commonFieldsDescription: 'Here you can edit settings or translate texts used in this content.',
  uploading: 'Uploading, please wait...',
  noFollow: 'Cannot follow field ":path".',
  editCopyright: 'Edit copyright',
  close: 'Close',
  tutorialAvailable: 'Tutorial available',
  editMode: 'Editing mode',
  listLabel: 'List',
  uploadError: 'File Upload Error',
  fileToLarge: 'The file you are trying to upload might be too large.',
  noSemantics: 'Error, could not load the content type form.'
};
